@@ -1,15 +1,14 @@
 package Data::Dumper::Compact;
-use strict;
-use warnings;
-
-our $VERSION = '0.001001';
-$VERSION =~ tr/_//d;
 
 use List::Util qw(sum);
 use Data::Dumper ();
 use Mu;
+use strictures 2;
 use namespace::clean;
 
+our $VERSION = '0.002000';
+$VERSION =~ tr/_//d;
+
 sub import {
   my ($class, $ddc, $opts) = @_;
   return unless ($ddc||'') eq 'ddc';
@@ -386,10 +385,6 @@ OO usage:
 
 =head1 DESCRIPTION
 
-A new module.
-
-=head1 WHY
-
 L<Data::Dumper::Compact>, henceforth referred to as DDC, was born because
 I was annoyed at valuable wasted whitespace paging through both
 L<Data::Dumper> and L<Data::Dump> based logs - L<Data::Dump> attempts to
